<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 10/24/2009 *
 * ===================                          Last change: 06/20/2010 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : daily_birthday.php                               *
 * -------------------------------------------------------------------- *
 * Short description : Sends out birthday mails on reset                *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Versendet Geburtstagsmails beim Reset            *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2013 by Mailer Developer Team                   *
 * For more information visit: http://mxchange.org                      *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	die();
} elseif ((!isHtmlOutputMode()) || (!isDailyResetEnabled())) {
	// Do not execute when script is in non-HTML mode
	return;
} elseif (!isExtensionActive('birthday')) {
	// Extension not active/installed
	if (isDebugModeEnabled()) logDebugMessage(__FILE__, __LINE__, 'Not resetting, needed extension ext-birthday disabled.');
	return;
}

// Debug line
//* DEBUG: */ logDebugMessage(__FILE__, __LINE__, 'Daily reset started.');

// Get current day (01 to 31), month (01 to 12) and year (4-digits year)
$day   = getDay();
$month = getMonth();
$year  = getYear();

// Init variables
$lastOnline = '';
$excludeSql = '';

// Shall I include only active members?
if ((getConfig('birthday_active')  == 'Y') && (isExtensionActive('autopurge')) && ((getApInactiveSince() > 0))) {
	$excludeSql = ' AND (UNIX_TIMESTAMP() - `d`.`last_online`) < {?ap_inactive_since?}';
} // END - if

// Is ext-holiday installed?
// @TODO Rewrite these if() blocks to a filter
if (isExtensionActive('holiday')) {
	// Exclude those as well
	$excludeSql .= " AND `d`.`holiday_active`='N'";
} // END - if

// Only confirmed members shall receive birthday mails...
$result_birthday = sqlQueryEscaped("SELECT
	`d`.`userid`,
	`d`.`email`,
	`d`.`birth_year`
FROM
	`{?_MYSQL_PREFIX?}_user_data` AS `d`
WHERE
	`d`.`status`='CONFIRMED'
	" . runFilterChain('user_exclusion_sql', $excludeSql) . " AND
	`d`.`birth_day`=%s AND
	`d`.`birth_month`=%s AND
	`d`.`birthday_sent` < (UNIX_TIMESTAMP() - ({?ONE_DAY?} * 364))
	" . $lastOnline . "
ORDER BY
	`d`.`userid` ASC",
	array($day, $month), __FILE__, __LINE__);

if (!ifSqlHasZeroNums($result_birthday)) {
	// Start sending out birthday mails
	while ($content = sqlFetchArray($result_birthday)) {
		// Calculate own timestamp for birthday and today
		$bd  = $content['birth_year'] + 12 * $month + 365 * $day;
		$now = $year  + 12 * $month + 365 * $day;

		// Simply subtract both values and you got the age... :)
		$age = $now - $bd;

		if (getBirthdayPoints() > 0) {
			// Add more entries to the array
			$content['age']    = $age;
			$content['check']  = '';

			// Generate long random code
			for ($idx = 0; $idx < 4; $idx++) {
				$content['check'] .= generateRandomCode('8', mt_rand(0, $month . $day), $content['userid'], ($age * ($idx + 1)));
			} // END - for

			// Insert row into database
			sqlQueryEscaped("INSERT INTO `{?_MYSQL_PREFIX?}_user_birthday` (`userid`, `points`, `chk_value`) VALUES (%s,{?birthday_points?},'%s' )",
				array(
					bigintval($content['userid']),
					$content['check']
				), __FILE__, __LINE__);

			// Load email template with confirmation link
			$message = loadEmailTemplate('member_birthday_confirm', $content, bigintval($content['userid']));
		} else {
			// Load default email template and fill in the age
			$message = loadEmailTemplate('member_birthday', $content, $content['userid']);
		}

		// Send email
		sendEmail($content['userid'], '{--MEMBER_HAPPY_BIRTHDAY_SUBJECT--}', $message);

		// Remember him that he has received a birthday mail
		sqlQueryEscaped("UPDATE `{?_MYSQL_PREFIX?}_user_data` SET `birthday_sent`=UNIX_TIMESTAMP() WHERE `userid`=%s LIMIT 1",
			array(bigintval($content['userid'])), __FILE__, __LINE__);
	} // END - while

	// Free memory
	sqlFreeResult($result_birthday);
} // END - if

// Debug line
//* DEBUG: */ logDebugMessage(__FILE__, __LINE__, 'Daily reset ended.');

// [EOF]
?>
