<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 09/28/2003 *
 * ===================                          Last change: 10/29/2004 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : what-email_details.php                           *
 * -------------------------------------------------------------------- *
 * Short description : See all email details of ordered mails           *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Alle Details einer gebuchten Mail ansehen        *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2013 by Mailer Developer Team                   *
 * For more information visit: http://mxchange.org                      *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if ((!defined('__SECURITY')) || (!isAdmin())) {
	die();
} // END - if

// Add description as navigation point
addYouAreHereLink('admin', __FILE__);

// Is 'sql_patches' updated?
if (!isExtensionInstalledAndNewer('sql_patches', '0.7.4')) {
	// No, abort here
	displayMessage(generateExtensionOutdatedMessage('sql_patches', '0.7.4'));
	return FALSE;
} // END - if

// Normal mails ordered by your members
$sql = "SELECT
	`id`,
	`sender`,
	`subject`,
	`text`,
	`receivers`,
	`payment_id`,
	`data_type`,
	`timestamp`,
	`url`,
	`target_send`,
	`mails_sent`,
	`cat_id`
FROM
	`{?_MYSQL_PREFIX?}_pool`
WHERE
	`data_type` IN('ADMIN','TEMP','NEW','ACTIVE')
ORDER BY
	`timestamp` DESC";

$WHO = '';
$SQL2 = '';

if ((isPostRequestElementSet('id')) && (isGetRequestElementSet('type')) && (postRequestElement('type') == 'normal')) {
	// Only a specific mail shall be displayed
	$sql = sprintf("SELECT
	`id`,
	`sender`,
	`subject`,
	`text`,
	`receivers`,
	`payment_id`,
	`data_type`,
	`timestamp`,
	`url`,
	`target_send`,
	`mails_sent`,
	`cat_id`
FROM
	`{?_MYSQL_PREFIX?}_pool`
WHERE
	`id`=%s
LIMIT 1",
		bigintval(getRequestElement('id'))
	);
	$WHO = '{--MAIL_ID--}' . ': ' . getRequestElement('id');
} elseif (isGetRequestElementSet('userid')) {
	// All mails by a specific member shall be displayed
	$sql = sprintf("SELECT
	`id`,
	`sender`,
	`subject`,
	`text`,
	`receivers`,
	`payment_id`,
	`data_type`,
	`timestamp`,
	`url`,
	`target_send`,
	`mails_sent`,
	`cat_id`
FROM
	`{?_MYSQL_PREFIX?}_pool`
WHERE
	`sender`=%s
ORDER BY
	`timestamp` DESC",
		bigintval(getRequestElement('userid'))
	);
	$WHO = '{--USER_ID--}' . ': ' . getRequestElement('userid');
}

// Init result_bonus
$result_bonus = FALSE;

if ((isExtensionActive('bonus')) && (empty($WHO))) {
	// Check for maximum pages
	$result_bonus = sqlQuery("SELECT
	`id`,
	`subject`,
	`text`,
	`receivers`,
	`points`,
	`time`,
	`data_type`,
	`timestamp`,
	`url`,
	`cat_id`,
	`target_send`,
	`mails_sent`,
	`clicks`,
	(`mails_sent` - `clicks`) AS `unconfirmed`
FROM
	`{?_MYSQL_PREFIX?}_bonus`
WHERE
	`is_notify`='N'
ORDER BY
	`timestamp` DESC", __FILE__, __LINE__);
} // END - if

// Check for maximum pages
$result_normal = sqlQuery($sql, __FILE__, __LINE__);

// Set offset an current page to default values
if (!isGetRequestElementSet('page')) setGetRequestElement('page', 1);

if (!isGetRequestElementSet('offset')) {
	if (isConfigEntrySet('mails_page')) {
		// Set config entry
		setGetRequestElement('offset', getMailsPage());
	} else {
		// Set default one
		setGetRequestElement('offset', 10);
	}
} // END - if

// Add limitation to SQL string
if (!(isPostRequestElementSet('id')) && (isGetRequestElementSet('type')) && (postRequestElement('type') == 'normal')) {
	// Create limitation line
	$add = ' LIMIT ' . (bigintval(getRequestElement('offset')) * bigintval(getRequestElement('page')) - bigintval(getRequestElement('offset'))) . ', ' . bigintval(getRequestElement('offset'));

	// For normal mails
	$sql .= $add;

	// For bonus mails
	if (!empty($SQL2)) $SQL2 .= $add;
} // END - if

// Run SQL query for normal mails
$result_list = sqlQuery($sql, __FILE__, __LINE__);
if ((!empty($SQL2)) && (empty($WHO))) {
	$result_bonus = sqlQuery($SQL2, __FILE__, __LINE__);
} // END - if

// Calculate pages
$numPages = '0';
if (isConfigEntrySet('mails_page')) {
	$numPages = round(sqlNumRows($result_normal) / getMailsPage() + 0.3);
} // END - if

// Free result
sqlFreeResult($result_normal);

$MAIL = FALSE;
if (!ifSqlHasZeroNums($result_list)) {
	// Init rows
	$OUT = '';

	// Walk through all entries
	while ($content = sqlFetchArray($result_list)) {
		// Unconfirmed mails and sent mails
		$result_uncon = sqlQueryEscaped("SELECT (`max_rec` - `clicks`) AS `unconfirmed` FROM `{?_MYSQL_PREFIX?}_user_stats` WHERE `pool_id`=%s LIMIT 1",
			array(bigintval($content['id'])), __FILE__, __LINE__);

		// Load and merge data
		$content = merge_array($content, sqlFetchArray($result_uncon));

		// Free result
		sqlFreeResult($result_uncon);

		// Unconfirmed mails
		$content['unconfirmed'] = generateUnconfirmedAdminLink($content['id'], ($content['unconfirmed']), 'normal');

		// Prepare content
		$content['timestamp']   = generateDateTime($content['timestamp'], 0);

		// Load row template
		$OUT .= loadTemplate('admin_list_emails_row', TRUE, $content);
	} // END - while

	// Free memory
	sqlFreeResult($result_list);

	// Add navigation (with change box and colspan=3)
	$content['nav'] = addEmailNavigation($numPages, getMailsPage(), FALSE, 3, TRUE);

	// Prepare content
	$content['rows'] = $OUT;
	$content['who'] = $WHO;

	// Mail orders are in pool so we can display them
	loadTemplate('admin_list_emails', FALSE, $content);

	$MAIL = TRUE;
	if ((isExtensionActive('bonus')) && (empty($WHO))) {
		// Only check if bonus extension is active
		if (!ifSqlHasZeroNums($result_bonus)) outputHtml('<br /><br />');
	} // END - if
} // END - if

if ((isExtensionActive('bonus')) && (empty($WHO))) {
	// Load bonus mails only when extension is active
	if (!ifSqlHasZeroNums($result_bonus)) {
		// Calculate pages
		$numPages = round(sqlNumRows($result_bonus) / getMailsPage() + 0.5);

		// List emails
		$OUT = '';
		while ($content = sqlFetchArray($result_bonus)) {
			// Add link to list_unconfirmed what-file
			$content['unconfirmed'] = generateUnconfirmedAdminLink($content['id'], $content['unconfirmed'], 'bonus');

			// Prepare content
			$content['timestamp']   = generateDateTime($content['timestamp'], 0);

			// Load row template
			$OUT .= loadTemplate('admin_list_bonus_emails_row', TRUE, $content);
		} // END - while

		// Add navigation (without change box but with colspan=3)
		$content['nav'] = addEmailNavigation($numPages, getMailsPage(), FALSE, 3, TRUE);

		// Prepare content
		$content['rows'] = $OUT;

		// Load main template
		loadTemplate('admin_list_bonus_emails', FALSE, $content);
		$MAIL = TRUE;
	} // END - if
} // END - if

if ($MAIL === FALSE) {
	// No mail orders fond
	displayMessage('{--ADMIN_NO_MAILS_IN_POOL--}');
} // END - if

// [EOF]
?>
