<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 02/28/2009 *
 * ===================                          Last change: 02/28/2009 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : session-functions.php                            *
 * -------------------------------------------------------------------- *
 * Short description : Session-relevant functions                       *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Sitzungsrelevante Funktionen                     *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2013 by Mailer Developer Team                   *
 * For more information visit: http://mxchange.org                      *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	die();
} // END - if

// Unset/set session variables
function setSession ($var, $value) {
	// Abort in CSS mode here
	if (isCssOutputMode()) {
		return TRUE;
	} // END - if

	// Trim value and session variable
	$var   = trim(secureString($var));
	$value = trim($value);

	// Is the session variable set?
	if (('' . $value . '' == '') && (isSessionVariableSet($var))) {
		// Remove the session
		//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'UNSET:' . $var . '=' . getSession($var));
		unset($GLOBALS['_SESSION'][$var]);
		if (isPhpVersionEqualNewer('5.3.0')) {
			// session_unregister() is deprecated as of 5.3.0
			return TRUE;
		} else {
			// PHP version < 5.3.0
			return session_unregister($var);
		}
	} elseif (('' . $value . '' != '') && (!isSessionVariableSet($var))) {
		// Set session
		//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'SET:' . $var . '=' . $value);
		$GLOBALS['_SESSION'][$var] = $value;
		if (isPhpVersionEqualNewer('5.3.0')) {
			// session_unregister() is deprecated as of 5.3.0
			return TRUE;
		} else {
			// PHP version < 5.3.0
			return session_register($var);
		}
	} elseif (!empty($value)) {
		// Update session
		//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'UPDATE:' . $var . '=' . $value);
		$GLOBALS['_SESSION'][$var] = $value;
		return TRUE;
	}

	// Ignored (but valid)
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, 'IGNORED:' . $var . '=' . $value);
	return TRUE;
}

// Check whether a session variable is set
function isSessionVariableSet ($var) {
	// Warning: DO NOT call logDebugMessage() from here, this will cause an endless loop
	return (isset($GLOBALS['_SESSION'][$var]));
}

// Returns whether the value of the session variable or NULL if not set
function getSession ($var) {
	// Default is not found ;-)
	$value = NULL;

	// Is the variable there?
	if (isSessionVariableSet($var)) {
		// Then  get it secured!
		$value = sqlEscapeString($GLOBALS['_SESSION'][$var]);
	} // END - if

	// Return the value
	//* DEBUG: */ logDebugMessage(__FUNCTION__, __LINE__, $var . '=' . $value);
	return $value;
}

// Get whole session array
function getSessionArray () {
	// Simply return it
	return $GLOBALS['_SESSION'];
}

// Destroy user session
function destroyMemberSession ($destroy = FALSE) {
	// Reset userid
	initMemberId();

	// Remove all user data from session
	if ($destroy === TRUE) {
		// Destroy whole session
		return destroySession();
	} else {
		return ((setSession('userid', '')) && (setSession('u_hash', '')));
	}
}

// Destroys the admin session
function destroyAdminSession ($destroy = FALSE) {
	// Kill maybe existing session variables including array elements
	setAdminId(0);
	setAdminMd5('');
	setAdminLast(0);

	// Set cache to FALSE
	$GLOBALS['isAdmin'] = FALSE;

	// Destroy session if requested and return status
	if ($destroy === TRUE) {
		return destroySession();
	} // END - if

	// All fine if the session shall not really be destroyed
	return TRUE;
}

// Destroys session and resets some "caches"
function destroySession () {
	// Unset "cache"
	unset($GLOBALS['isSessionValid']);

	// Destroy session
	return session_destroy();
}

// Checks whether the session is valid
function isSessionValid () {
	// Is there cache?
	if (!isset($GLOBALS[__FUNCTION__])) {
		// Then determine it
		$GLOBALS[__FUNCTION__] = ((isset($GLOBALS['valid_session'])) && ($GLOBALS['valid_session'] === TRUE) && (isset($_COOKIE[session_name()])));
	} // END - if

	// Return cache
	return $GLOBALS[__FUNCTION__];
}

// Checks whether all given session data is set
function isSessionDataSet ($sessionData) {
	// Default is set
	$isset = TRUE;

	// Check all
	foreach ($sessionData as $key) {
		// Is this element set?
		$isset = (($isset) && (isSessionVariableSet($key)));
	} // END - foreach

	// Return result
	return $isset;
}

// [EOF]
?>
