<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 08/29/2003 *
 * ===================                          Last change: 12/03/2004 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : stylesheet.php                                   *
 * -------------------------------------------------------------------- *
 * Short description : Stylesheets are stored here                      *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Style-Sheets werden hier abgelegt                *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2013 by Mailer Developer Team                   *
 * For more information visit: http://mxchange.org                      *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	die();
}

// Default styles
$stylesList = array(
		'general.css',
		'ajax.css',
);

// Add stylesheet for installation
if ((isInstaller())) {
	array_push($stylesList, 'install.css');
} // END - if

// When no CSS output-mode is set, set it to file-output
if (!isConfigEntrySet('css_php')) {
	setConfigEntry('css_php', 'FILE');
} // END - if

// Get current theme
$currentTheme = getCurrentTheme();

// Has the theme changed?
if ($currentTheme != getSession('mailer_theme')) {
	// Then set it
	setMailerTheme($currentTheme);
} // END - if

// Output CSS files or content or link to css.php ?
if ((isCssOutputMode()) || (getCssPhp() == 'DIRECT')) {
	// Load CSS files
	$stylesList = merge_array($stylesList, getExtensionCssFiles());

	// Generate base path
	$basePath = getBasePathFromTheme($currentTheme);

	// Output inclusion lines
	foreach ($stylesList as $value) {
		// Only include found CSS files (to reduce 404 requests)
		$FQFN = $basePath . '/' . $value;

		// Do include only existing files and whose are not empty
		if ((isFileReadable($FQFN)) && (filesize($FQFN) > 0)) {
			switch (getCssPhp()) {
				case 'DIRECT': // Just link them (unsupported)
					$GLOBALS['__page_header'] .= '<link rel="stylesheet" type="text/css" href="{%url=theme/' . getCurrentTheme() . '/' . $value . '%}" />';
					break;

				case 'FILE': // Output contents
					$GLOBALS['__page_header'] .= readFromFile($FQFN);
					break;

				default: // Invalid mode!
					reportBug(__FILE__, __LINE__, sprintf('Invalid css_php value %s detected.', getCssPhp()));
					break;
			} // END - switch
		} // END - if
	} // END - foreach
} elseif ((isHtmlOutputMode()) || (getCssPhp() == 'INLINE')) {
	// Load CSS files
	$stylesList = merge_array($stylesList, getExtensionCssFiles());

	// Generate base path
	$basePath = getBasePathFromTheme(getCurrentTheme());

	// Output inclusion lines
	$OUT = '';
	foreach ($stylesList as $value) {
		// Only include found CSS files (to reduce 404 requests)
		$FQFN = $basePath . '/' . $value;

		// Do include only existing files and whose are not empty
		if ((isFileReadable($FQFN)) && (filesize($FQFN) > 0)) {
			// Load CSS content
			$OUT .= readFromFile($FQFN);
		} // END - if
	} // END - foreach

	// Load template
	$GLOBALS['__page_header'] .= loadTemplate('css_inline', TRUE, $OUT);
} else {
	// Now we load all CSS files from css.php!
	$OUT = '<link rel="stylesheet" type="text/css" href="{%url=css.php';
	if ((isInstaller())) {
		// Default theme first
		$OUT .= '?theme=' . getCurrentTheme() . '&amp;installing=1';
	} else {
		// Add SVN revision to bypass caching problems
		$OUT .= '?rev=' . getCurrentRepositoryRevision();
	}

	// Close tag
	$GLOBALS['__page_header'] .= $OUT . '%}{%ext,version=sql_patches%}" />';
}

// [EOF]
?>
